@@ -258,9 +258,9 @@ class TaurusSynopticWidget(SynopticWidget, TaurusWidget):
         The default behavior for right clicking a device is to open a panel.
         """
         if kind == "model" and self.registry.device_validator.isValid(name):
-            if name.lower() in self._panels:
+            if name in self._panels:
 
-                widget = self._panels[name.lower()]
+                widget = self._panels[name]
                 print("Found existing panel for %s:" % name, widget)
                 if not widget.isVisible():
                     widget.show()
@@ -287,7 +287,7 @@ class TaurusSynopticWidget(SynopticWidget, TaurusWidget):
             # monkey patch to cleanup on close...
             widget.closeEvent = lambda _: self._cleanup_panel(widget)
             # keep a reference to the widget
-            self._panels[name.lower()] = widget
+            self._panels[name] = widget
             widget.show()
 
     def _cleanup_panel(self, w):
@@ -295,13 +295,22 @@ class TaurusSynopticWidget(SynopticWidget, TaurusWidget):
         In the long run it seems like a good idea to try and clean up
         closed panels. In particular, the Taurus polling thread can
         become pretty bogged down.
+
+        Panels are added to the internal dict using the device name that was clicked as key.
+        This name is saved as Window title.
         """
         if self.registry:
             with self.registry.lock:
-                print("cleaning up panel for", w.getModel(), "...")
-                self._panels.pop(str(w.getModel()).lower(), None)
-                w.setModel(None)
-                print("done!")
+                name = w.windowTitle()
+                print("cleaning up panel for", name, "...")
+                panel = self._panels.pop(name, None)
+                if panel is None:
+                    print(f"{name} not found in {self._panels}")
+                    # Don't set the model to None in case this panel is present
+                    # under another device name in the dict
+                else:
+                    print(f"{name} removed")
+                    w.setModel(None)
 
     # Note: the tooltip stuff is broken and not currently in use.
     # Currently there is only the default tooltip which displays the
